
/*********************************************************************************\

PROGRAM:                OUTPATIENT_2010_PUF_READIN.sas

DESCRIPTION:            To read csv format Outpatient PUF to SAS dataset

INPUT FILES:            BSA_OUTPATIENT_PUF_2010.csv

OUTPUT FILES:           BSA_OUTPATIENT_PUF_2010.sas7bdat

OTHER OUTPUT:           Contents, proc print and freq distribution

\*********************************************************************************/

FOOTNOTE 'BSA_OUTPATIENT_PUF_2010.sas';

* Log/List Options *;
options ls=120 ps=42 missing=' ' nocenter validvarname=upcase compress=binary;

* Input File Reference *;
filename in '.\2010_BSA_Outpatient_PUF.csv';     * <-- Place Input File Path Here *;

* Output SAS Library *;
libname PUF '.';     * <-- Place Output Library Path Here *;

* Lookup File References *;
filename lookup ". \all_icd9_codes.csv";     * <-- Place Output Library Path Here *

*Formats Code : Formats will be included if the following is uncommented *;
/*  
Proc format;

Value SEXF
        1 = 'MALE'
        2 = 'FEMALE'
;

Value AGEF
        1       = 'Under 65'
        2       = '65 - 69'
        3       = '70 - 74 '
        4       = '75 - 79 '
        5       = '80 - 84 '
        6       = '85 or Older'
;
 
run;
*/

data PUF.BSA_OUTPATIENT_PUF_2010 (label="OUTPATIENT BENEFICIARY PUBLIC USE FILE");

infile in dlm = ',' dsd missover truncover firstobs = 2 ;

  * Input Record *;
  input BENE_SEX_IDENT_CD
        BENE_AGE_CAT_CD
        OP_CLM_ICD9_DIAG_CD              :$5.
        OP_HCPCS_CD                      :$5.
        OP_HCPCS_UNIT_CNT
        OP_HCPCS_PMT_AMT
  ;

  *** Uncomment following to apply formats ;
  /*
  format BENE_SEX_IDENT_CD               SEXF.
         BENE_AGE_CAT_CD                 AGEF.
        ;
   */

  * Labels *;
  label BENE_SEX_IDENT_CD       = "Beneficiary Gender Code "
        BENE_AGE_CAT_CD         = "Beneficiary Age Category code "
        OP_CLM_ICD9_DIAG_CD     = "ICD9 Primary Diagnosis Code"
        OP_HCPCS_CD             = "HCPCS Procedure Code"
        OP_HCPCS_UNIT_CNT       = "Count of Services"
        OP_HCPCS_PMT_AMT        = "Medicare Payment Amount"
  ;

run;


/*Uncomment this for creating SAS DATASET with descriptions for ICD9 CODES*/
 /*
data ICD9_CODES;
infile lookup  dsd  missover truncover firstobs=2 lrecl=310;
input  icd9_cd :$4. ICD9_DESCRIPTION :$175. ;
run;

proc sql;
create table PUF.BSA_OUTPATIENT_PUF_2010 as
select a.*, b.ICD9_DESCRIPTION
from  PUF.BSA_OUTPATIENT_PUF_2010 a left join ICD9_CODES b
on a.OP_CLM_ICD9_DIAG_CD= b.ICD9_CD;
quit;
*/   

title "OUTPATIENT BENEFICIARY PUBLIC USE FILE";
proc contents data=PUF.BSA_OUTPATIENT_PUF_2010 varnum;

proc print data=PUF.BSA_OUTPATIENT_PUF_2010(obs=10);
  title2 "Sample Listing - 10 Rows";
run;

proc freq data=PUF.BSA_OUTPATIENT_PUF_2010;
  title2 "Frequencies";
  table BENE_SEX_IDENT_CD
        BENE_AGE_CAT_CD
        OP_CLM_ICD9_DIAG_CD
        OP_HCPCS_CD
        OP_HCPCS_UNIT_CNT
        OP_HCPCS_PMT_AMT /missing;
run;

* End of Program *;


